const System = require("../../../system");
var settings = require("../../../../config/settings");
var md5 = require("md5-node");
const querystring = require('querystring');
class EnterpriseService {
    constructor() {
        this.gxgyUrl = settings.reqEsAddrIc() + "enterprise_chain_gxgy/_search";
        this.licenseUrl = settings.reqEsAddrIc() + "enterprise_chain_license/_search";
        this.gameUrl = settings.reqEsAddrIc() + "enterprise_chain_game/_search";
        this.ipUrl = settings.reqEsAddrIc() + "bigdata_ip_back/_search";
        this.qccUrl = "http://api.qichacha.com/ECIV4/GetDetailsByName";
    };

    async getQccBranches(obj){//获取企业的分支机构（从企查查获取）
        var author = obj.author == null || obj.author == "" || obj.author == "undefined" ? "" : obj.author;
        if (author == "") {
            return System.getResult2(null, "企业名称不能为空");
        }
        author = await this.getConvertSemiangleStr(author);
        var Timespan = parseInt(Date.now()/1000);//秒级时间戳
        var Token = md5("74805b02bf2f46feaa3bdb24feecfbc1" + Timespan.toString() + "5D92FB79060AFCBFD3D4BC7AE7A3D225");
        Token = Token.toUpperCase();
        var params = {
            key:"74805b02bf2f46feaa3bdb24feecfbc1",
            keyword:author
        }
        var rc = System.getObject("util.restClient");
        var data= querystring.stringify(params);
        var rtn=null;
        try{
          rtn=await rc.execGetZZ(params,this.qccUrl,Token,Timespan);
          var result = JSON.parse(rtn.stdout);
          if (result.Status == "200"){
            return System.getResult2(result.Result.Branches, "获取数据出错");
          }
          else if (result.Status == "201"){
            return System.getResult2(null, "查询无结果");
          }
          else{
            return System.getResult2(null, "获取数据出错");
          }
          
        }catch(e){
          return System.getResult2(null, "获取数据出错");
        }

    };

    async getConvertSemiangleStr(str) {//半角转全角
        var result = "";
        var len = str.length;
        for (var i = 0; i < len; i++) {
            var cCode = str.charCodeAt(i);
            //全角与半角相差（除空格外）：65248（十进制）
            cCode = (cCode >= 0xFF01 && cCode <= 0xFF5E) ? (cCode - 65248) : cCode;
            //处理空格
            cCode = (cCode == 0x03000) ? 0x0020 : cCode;
            result += String.fromCharCode(cCode);
        }
        return result;
    };

    async gxCountByAuthor(obj) {//获取企业高薪信息数量
        var author = obj.author == null || obj.author == "" || obj.author == "undefined" ? "" : obj.author;
        if (author == "") {
            return System.getResult2(null, "企业名称不能为空");
        }
        author = await this.getConvertSemiangleStr(author);
        var params = {
            "query": {
                "term": {
                    "companyName.raw": author
                }
            },
            "size": 0
        };

        var rc = System.getObject("util.execClient");
        var rtn = null;
        var requrl = this.gxgyUrl;
        try {
            rtn = await rc.execPost(params, requrl);
            var j = JSON.parse(rtn.stdout);
            return System.getResult2(j.hits.total, null);
        }
        catch (e) {
            return System.getResult2(null, "获取数据出错");
        };

    };

    async gxListByAuthor(obj) {//获取企业高薪信息列表
        var author = obj.author == null || obj.author == "" || obj.author == "undefined" ? "" : obj.author;
        var pagesize = obj.page_size == null || obj.page_size == "" || obj.page_size == "undefined" ? 10 : obj.page_size;
        var from = obj.current_page == null || obj.current_page == "" || obj.current_page == "undefined" ? 0 : Number((obj.current_page - 1) * pagesize);

        if (author == "") {
            return System.getResult2(null, "企业名称不能为空");
        }
        author = await this.getConvertSemiangleStr(author);
        var params = {
            "query": {
                "term": {
                    "companyName.raw": author
                }
            },
            "from": from,
            "size": pagesize,
            "_source": [
                "techType",
                "area",
                "certificateNo",
                "address",
                "year",
                "businessScope"
            ],
            "sort": [
                {
                    "year": "desc"
                }
            ]
        };
        var rc = System.getObject("util.execClient");
        var rtn = null;
        var requrl = this.gxgyUrl;
        try {
            rtn = await rc.execPost(params, requrl);
            var j = JSON.parse(rtn.stdout);
            var res = {};
            res.total = 0;
            res.data = [];
            if (j.hits.total > 0) {
                res.total = j.hits.total;
                for (let index = 0; index < j.hits.hits.length; index++) {
                    const element = j.hits.hits[index];
                    if (element) {
                        res.data.push(element["_source"]);
                    }
                }
            }
            return System.getResult2(res, null);
        }
        catch (e) {
            return System.getResult2(null, "获取数据出错");
        };
    };

    async gameCountByAuthor(obj) {//获取游戏出版及运营数量
        var author = obj.author == null || obj.author == "" || obj.author == "undefined" ? "" : obj.author;
        var type = obj.type == null || obj.type == "" || obj.type == "undefined" ? "" : obj.type;
        if (author == "" || type == "") {
            return System.getResult2(null, "企业名称和证照类型不能为空");
        }
        author = await this.getConvertSemiangleStr(author);
        var params = null;
        if (type == "网络游戏出版备案") {
            params = {
                "query": {
                    "term": {
                        "publishing_unit.raw": author
                    }
                },
                "size": 0
            }
        }
        else if (type == "网络游戏运营备案") {
            params = {
                "query": {
                    "term": {
                        "operation_unit.raw": author
                    }
                },
                "size": 0
            }
        }
        else {
            return System.getResult2(null, "证照类型不正确");
        }


        var rc = System.getObject("util.execClient");
        var rtn = null;
        var requrl = this.gameUrl;
        try {
            rtn = await rc.execPost(params, requrl);
            var j = JSON.parse(rtn.stdout);
            return System.getResult2(j.hits.total, null);
        }
        catch (e) {
            return System.getResult2(null, "获取数据出错");
        };

    };

    async gameListByAuthor(obj) {//获取游戏出版信息列表
        var author = obj.author == null || obj.author == "" || obj.author == "undefined" ? "" : obj.author;
        var type = obj.type == null || obj.type == "" || obj.type == "undefined" ? "" : obj.type;
        var pagesize = obj.page_size == null || obj.page_size == "" || obj.page_size == "undefined" ? 10 : obj.page_size;
        var from = obj.current_page == null || obj.current_page == "" || obj.current_page == "undefined" ? 0 : Number((obj.current_page - 1) * pagesize);

        if (author == "" || type == "") {
            return System.getResult2(null, "企业名称和证照类型不能为空");
        }
        author = await this.getConvertSemiangleStr(author);
        var params = null;
        if (type == "网络游戏出版备案") {
            params = {
                "query": {
                    "term": {
                        "publishing_unit.raw": author
                    }
                },
                "from": from,
                "size": pagesize,
                "_source": [
                    "game_name",
                    "declaration_category",
                    "publishing_unit",
                    "operation_unit",
                    "symbol",
                    "publishing_number",
                    "publish_time",
                    "publishing_record",
                    "operation_record",
                    "industry_type"
                ],
                "sort": [
                    {
                        "publish_time": "desc"
                    }
                ]
            }
        }
        else if (type == "网络游戏运营备案") {
            params = {
                "query": {
                    "term": {
                        "operation_unit.raw": author
                    }
                },
                "from": from,
                "size": pagesize,
                "_source": [
                    "game_name",
                    "declaration_category",
                    "publishing_unit",
                    "operation_unit",
                    "symbol",
                    "publishing_number",
                    "publish_time",
                    "publishing_record",
                    "operation_record",
                    "industry_type"
                ],
                "sort": [
                    {
                        "publish_time": "desc"
                    }
                ]
            }
        }
        else {
            return System.getResult2(null, "证照类型不正确");
        }


        var rc = System.getObject("util.execClient");
        var rtn = null;
        var requrl = this.gameUrl;
        try {
            rtn = await rc.execPost(params, requrl);
            var j = JSON.parse(rtn.stdout);
            var res = {};
            res.total = 0;
            res.data = [];
            if (j.hits.total > 0) {
                res.total = j.hits.total;
                for (let index = 0; index < j.hits.hits.length; index++) {
                    const element = j.hits.hits[index];
                    if (element) {
                        res.data.push(element["_source"]);
                    }
                }
            }
            return System.getResult2(res, null);
        }
        catch (e) {
            return System.getResult2(null, "获取数据出错");
        };

    };

    async licenseCountByAuthor(obj) {//获取企业证照信息数量
        var author = obj.author == null || obj.author == "" || obj.author == "undefined" ? "" : obj.author;
        if (author == "") {
            return System.getResult2(null, "企业名称不能为空");
        }
        author = await this.getConvertSemiangleStr(author);
        var params = {
            "query": {
                "term": {
                    "companyName.raw": author
                }
            },
            "from": 0,
            "size": 0,
            "aggregations": {
                "group_by_licence": {
                    "terms": {
                        "field": "licence",
                        "size": 1000
                    }
                }

            }
        };

        var rc = System.getObject("util.execClient");
        var rtn = null;
        var requrl = this.licenseUrl;
        try {
            rtn = await rc.execPost(params, requrl);
            var j = JSON.parse(rtn.stdout);
            var res = {};
            res.total = 0;
            res.data = [];
            if (j.hits.total > 0) {
                res.total = j.hits.total;
                for (let index = 0; index < j.aggregations.group_by_licence.buckets.length; index++) {
                  const element = j.aggregations.group_by_licence.buckets[index];
                  if (element) {
                    res.data.push(element);
                  }
                }
            }
            return System.getResult2(res, null);
        }
        catch (e) {
            return System.getResult2(null, "获取数据出错");
        };

    };

    async licenseListByAuthor(obj) {//获取企业证照信息列表
        var author = obj.author == null || obj.author == "" || obj.author == "undefined" ? "" : obj.author;
        var licence = obj.licence == null || obj.licence == "" || obj.licence == "undefined" ? "" : obj.licence;
        var pagesize = obj.page_size == null || obj.page_size == "" || obj.page_size == "undefined" ? 10 : obj.page_size;
        var from = obj.current_page == null || obj.current_page == "" || obj.current_page == "undefined" ? 0 : Number((obj.current_page - 1) * pagesize);

        if (author == "" || licence == "") {
            return System.getResult2(null, "企业名称和证照类型不能为空");
        }
        author = await this.getConvertSemiangleStr(author);
        var params = {
            "query": {
                "bool": {
                    "must": [
                        {
                            "term": {
                                "companyName.raw": author
                            }
                        },
                        {
                            "term": {
                                "licence": licence
                            }
                        },
                    ]
                }

            },
            "from": from,
            "size": pagesize,
            "_source": [
                "companyName",
                "licence",
                "licence_no",
                "service_category",
                "start_date",
                "end_date",
                "industry_type"
            ],
            "sort": [
                {
                    "end_date": "desc"
                }
            ]
        };
        var rc = System.getObject("util.execClient");
        var rtn = null;
        var requrl = this.licenseUrl;
        try {
            rtn = await rc.execPost(params, requrl);
            var j = JSON.parse(rtn.stdout);
            var res = {};
            res.total = 0;
            res.data = [];
            if (j.hits.total > 0) {
                res.total = j.hits.total;
                for (let index = 0; index < j.hits.hits.length; index++) {
                  const element = j.hits.hits[index];
                  if (element) {
                    res.data.push(element["_source"]);
                  }
                }
            }
            return System.getResult2(res, null);
        }
        catch (e) {
            return System.getResult2(null, "获取数据出错");
        };
    };

    async ipCountByAuthor(obj) {//获取企业域名信息数量
        var author = obj.author == null || obj.author == "" || obj.author == "undefined" ? "" : obj.author;
        if (author == "") {
            return System.getResult2(null, "企业名称不能为空");
        }
        author = await this.getConvertSemiangleStr(author);
        var params = {
            "query": {
                "term": {
                    "company_name.raw": author
                }
            },
            "size": 0
        };

        var rc = System.getObject("util.execClient");
        var rtn = null;
        var requrl = this.ipUrl;
        try {
            rtn = await rc.execPost(params, requrl);
            var j = JSON.parse(rtn.stdout);
            return System.getResult2(j.hits.total, null);
        }
        catch (e) {
            return System.getResult2(null, "获取数据出错");
        };

    };

    async ipListByAuthor(obj) {//获取企业域名信息列表
        var author = obj.author == null || obj.author == "" || obj.author == "undefined" ? "" : obj.author;
        var pagesize = obj.page_size == null || obj.page_size == "" || obj.page_size == "undefined" ? 10 : obj.page_size;
        var from = obj.current_page == null || obj.current_page == "" || obj.current_page == "undefined" ? 0 : Number((obj.current_page - 1) * pagesize);

        if (author == "") {
            return System.getResult2(null, "企业名称不能为空");
        }
        author = await this.getConvertSemiangleStr(author);
        var params = {
            "query": {
                "term": {
                    "company_name.raw": author
                }
            },
            "from": from,
            "size": pagesize,
            "_source": [
                "company_name",
                "card_num",
                "web_adress",
                "phone",
                "phone1",
                "phone2"
            ]
        };
        var rc = System.getObject("util.execClient");
        var rtn = null;
        var requrl = this.ipUrl;
        try {
            rtn = await rc.execPost(params, requrl);
            var j = JSON.parse(rtn.stdout);
            var res = {};
            res.total = 0;
            res.data = [];
            if (j.hits.total > 0) {
                res.total = j.hits.total;
                for (let index = 0; index < j.hits.hits.length; index++) {
                  const element = j.hits.hits[index];
                  if (element) {
                    res.data.push(element["_source"]);
                  }
                }
            }
            return System.getResult2(res, null);
        }
        catch (e) {
            return System.getResult2(null, "获取数据出错");
        };
    };
}
module.exports = EnterpriseService;

// var tesk = new EnterpriseService();
// var parm = {
//     author: "淘宝(中国)软件有限公司"
// };
// tesk.getQccBranches(parm).then(function (result) {
//     console.log(result);
//    // console.log(result.data.data[0]);
// }).catch(function (e) {
//     console.log(e);
// });

